# -*- coding: UTF-8 -*-
# Author: Hu Min
# Date: 2021-11-30
import pandas as pd
from pandas import json_normalize
import logging
import logging.config
from utils.opensearch import get_client
import json

def daily_basic(ts_code=None, trade_date = None, start_date=None, end_date=None):
    """
    获取每日指标数据
    :param ts_code: 股票代码
    :param trade_date: 交易日期 
    :param start_date: 开始日期 (YYYYMMDD)
    :param end_date: 结束日期 (YYYYMMDD)
    :return:
    """
    logging.debug("get daily basic, ts_code: %s, trade_date: %s, start_date: %s, end_date: %s", ts_code, trade_date, start_date, end_date)
    query = []
    if ts_code is not None:
        query.append({"match": {"ts_code.keyword":  ts_code }})
    if trade_date is not None:
        query.append({"match": {"trade_date": trade_date}})
    if start_date is not None and end_date is not None:
        query.append({"range": {"trade_date": {"gte":  start_date, "lte":  end_date}}})
    elif start_date is not None and end_date is None:
        query.append({"range": {"trade_date": {"gte":  start_date}}})
    elif start_date is None and end_date is not None:
        query.append({"range": {"trade_date": {"lte":  end_date}}})

    print(query)
    logging.info(json.dumps(query))
    return get_client().search_by_condition(index='daily_basic', must=query, size=100000)

if __name__ == '__main__':
    print(daily_basic(ts_code='000001.SZ', trade_date='20190401'))


# -*- coding: UTF-8 -*-
# Author: Hu Min
# Date: 2021-11-30
import pandas as pd
from pandas import json_normalize
import logging
import logging.config
from utils.opensearch import get_client

def concept_list(src = 'ts'):
    """获取概念股分类，目前只有ts一个来源
    :param src:
    """
    logging.debug("get concept list")
    return get_client().search(index='concept', body={"size":1000000,"query":{"bool":{"must":[{"match":{"src":src}}],"must_not":[],"should":[]}}})

def concept_detail(id=None, ts_code=None):
    """获取概念股分类明细数据
    :param src:
    """
    logging.debug("get concept detail, id: %s, ts_code: %s" % (id, ts_code))
    if ts_code is None and id is not None:
        return get_client().search(index='concept_detail', body={"size":1000000,"query":{"bool":{"must":[{"match":{"id":id}}],"must_not":[],"should":[]}}})
    if id is None and ts_code is not None:
        return get_client().search(index='concept_detail', body={"size":1000000,"query":{"bool":{"must":[{"match":{"ts_code.keyword":ts_code}}],"must_not":[],"should":[]}}})
    return None

if __name__ == '__main__':
    print(concept_list('ts'))



# -*- coding: UTF-8 -*-

import pkgutil

__version__ = '1.0.0'
__author__ = 'Hu Min'

def get_version():
    return __version__

def init():
    for _, modname, ispkg in pkgutil.walk_packages(path=__path__, prefix='yqdata.'):
        if ispkg:
            continue
        try:
            __import__(modname)
        except ImportError:
            print("can not find mod [{}], ignored".format(modname))
            continue
        
init()


# -*- coding: utf-8 -*-

#         详细的授权流程，请联系 public@ricequant.com 获取。
import sys
import setuptools

requirements = [
    'requests',
    'numpy',
    'pandas',
    'python-dateutil',
    'six',
    'logbook',
    'click >=7.0.0',
    'jsonpickle',
    'simplejson',
    'PyYAML',
    'tabulate',
    'rqrisk',
    'h5py',
    'matplotlib >=2.2.0',
]

with open("README.md", "r") as fh:
    long_description = fh.read()

if sys.version_info < (3, 5):
    requirements.append('typing')

if sys.version_info.major == 2 and sys.version_info.minor == 7:
    requirements.extend([
        "enum34",
        "fastcache",
        "funcsigs",
        "backports.tempfile",
    ])

setuptools.setup(
    name="yqdata",
    version="1.0.0",
    author="Hu Min",
    author_email="humin11@icloud.com",
    description="小容量化数据平台",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="http://gitlab.intellinker.com/intellinker-prd-rong-001/jupyterhub-deploy-01",
    packages=setuptools.find_packages(),
    install_requires=['Pillow>=5.1.0', 'numpy==1.14.4'],
    entry_points={
        'console_scripts': [
            'yqdata=yqdata:main'
        ],
    },
    classifiers=[
        'Programming Language :: Python',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
